# 飞书多维表格自动AI对话工具

这是一个基于飞书多维表格数据的自动化AI对话工具，可以通过读取飞书表格数据，自动与达人进行实际的电子邮件对话。

## 主要功能

1. **读取飞书多维表格数据**：从指定的飞书表格获取达人信息
2. **检测重复邮箱**：自动识别表格中的重复邮箱记录
3. **创建知识库**：为每位达人自动创建知识库，存储历史对话内容
4. **设置用户总目标**：针对每位达人设置对话目标
5. **自动化AI对话**：
   - 发送初始邮件给达人
   - 监听达人回复
   - 生成智能回复并通过Gmail发送
   - 检测目标达成状态
6. **发送提醒**：当对话目标达成时，自动通知团队领导

## 核心优势

- **真实邮件互动**：通过Gmail实际发送和接收邮件，与达人进行真实互动
- **智能回复生成**：使用DeepSeek AI生成专业、有针对性的回复
- **目标导向**：所有对话都围绕预设目标进行，提高对话效率
- **自动化处理**：减少人工干预，自动化处理大量达人沟通
- **灵活控制**：支持强制发送模式，可随时人工介入

## 使用方法

### 1. 处理飞书表格

```bash
# 从飞书多维表格读取数据并处理重复邮箱
python feishu_ai_chat.py process_table --table_id tbl3oikG3F8YYtVA --view_id vewSOIsmxc --app_id cli_a5c97daacb9e500d --app_secret fdVeOCLXmuIHZVmSV0VbJh9wd0Kq1o5y

# 自动处理并启动对话
python feishu_ai_chat.py process_table --table_id tbl3oikG3F8YYtVA --view_id vewSOIsmxc --auto_chat
```

### 2. 执行自动对话

```bash
# 检查新回复并回应
python feishu_ai_chat.py auto_chat --email example@gmail.com

# 强制发送新邮件
python feishu_ai_chat.py auto_chat --email example@gmail.com --force_send --content "自定义邮件内容"
```

### 3. 设置用户总目标

```bash
python feishu_ai_chat.py set_goal --email example@gmail.com --goal "与达人建立联系并了解其账号情况，评估合作潜力，处理合作需求，最终目标是达成合作并签约。"
```

### 4. 检查目标完成状态

```bash
python feishu_ai_chat.py check_goal --email example@gmail.com
```

## API 使用方法

系统提供RESTful API接口，详见 [API_README.md](API_README.md)。

## 实际对话流程

1. **初始化阶段**：
   - 系统读取飞书表格数据
   - 识别达人邮箱并创建知识库
   - 设置对话总目标

2. **首次对话**：
   - 系统发送第一封邮件给达人
   - 邮件内容包含简短介绍和合作意向

3. **等待回复**：
   - 系统监听达人回复
   - 当收到回复后，自动同步到知识库

4. **自动回复**：
   - 分析达人回复内容
   - 生成智能回复
   - 通过Gmail发送回复邮件

5. **目标检测**：
   - 持续检测对话是否达成预设目标
   - 当达成目标时发送通知

6. **对话总结**：
   - 生成对话总结，包括关键点和后续行动项

## 注意事项

1. 使用前请确保已配置Gmail集成和正确的API密钥
2. 达人的邮件回复可能需要一定时间，建议设置定时任务检查新回复
3. 在自动对话过程中，可以随时通过强制发送模式介入对话
4. 对话总目标应该明确具体，这将影响AI生成回复的质量
5. 执行自动对话前，请确保飞书表格中的达人邮箱准确

## 技术说明

- 使用飞书开放平台API读取多维表格数据
- 通过Gmail API实现邮件发送和接收
- 利用DeepSeek API生成智能回复和对话总结
- Django框架提供Web API接口 